==> nextcloud-28.0.8.tgz: nextcloud/apps/activity/l10n/es_CO.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "Recent activity" : "Actividad resiente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de actividad diaria para 1%s",
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad a 1%s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "Mail" : "Correo",
    "Push" : "Notificación",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas visualizar un registro de actividades sobre ellos, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta app permite a la gente ver las acciones relacionadas con sus archivos y datos en Nextcloud.\n\t\tCada persona puede configurar sus ajustes de actividad en las configuraciones personales,\n\t\tpara seleccionar que actividades deberían ser notificadas en sus teléfonos móviles, enviadas por correo\n\t\to si un resumen diario se envía cada mañana.\n\t\tHay mas información disponible en la documentación de Activity.",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Open {filename}" : "Abrir {Nombre_de_archivo}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Activity settings" : "Ajustes de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar el enlace del feed RSS",
    "Personal notification settings" : "Ajustes de notificaciones personales",
    "Unable to load the activity list" : "No se pudo cargar la lista de actividades",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar notificaciones por email",
    "Choose for which activities you want to get an email or push notification." : "Escoja cuales actividades quiere enviar por correo o por notificaciones.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Daily activity summary" : "Resumen de actividad diaria",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Configure los ajustes de notificación predeterminados para nuevas cuentas de usuario.",
    "Unable to save the settings" : "No se ha podido guardar la configuración",
    "No more events to load" : "No hay más eventos por cargar",
    "Copied!" : "¡Copiado!",
    "Not supported!" : "¡No soportado!",
    "Press ⌘-C to copy." : "Presiona ⌘-C para copiar.",
    "Press Ctrl-C to copy." : "Presiona Ctrl-C para copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restringido)",
    "There are no events for this filter" : "No hay eventos para este filtro"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-31.0.9.tgz: nextcloud/apps/activity/l10n/es_CO.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Fuente de actividad personal para %s",
    "Your feed URL is invalid" : "La URL de tu fuente de es inválida",
    "Activity feed for %1$s" : "Flujo de actividad para %1$s",
    "Activity feed" : "Fuente de actividad",
    "Your settings have been updated." : "Tus configuraciones se han actualizado.",
    "Settings have been updated." : "Las configuraciones han sido actualizadas",
    "remote user" : "Usuario remoto",
    "Recent activity" : "Actividad resiente",
    "No activities" : "No hay actividades",
    "More activities" : "Más actividades",
    "Daily activity summary for %s" : "Resumen de actividad diaria para 1%s",
    "_and %n more…_::_and %n more…_" : ["y %n mas...","y %n mas...","y %n mas..."],
    "All activities" : "Todas las actividades",
    "By others" : "Por otros",
    "By you" : "Por usted",
    "Activity at %s" : "Actividad a 1%s",
    "Hello %s" : "Hola %s",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Se tuvo algo de actividad en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más","y %n más"],
    "Mail" : "Correo",
    "Push" : "Notificación",
    "Activity" : "Actividad",
    "Notifications" : "Notificaciones",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite a las personas visualizar un registro de actividades sobre ellos, sus archivos u otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta app permite a la gente ver las acciones relacionadas con sus archivos y datos en Nextcloud.\n\t\tCada persona puede configurar sus ajustes de actividad en las configuraciones personales,\n\t\tpara seleccionar que actividades deberían ser notificadas en sus teléfonos móviles, enviadas por correo\n\t\to si un resumen diario se envía cada mañana.\n\t\tHay mas información disponible en la documentación de Activity.",
    "Send email" : "Enviar correo electrónico",
    "Send push notification" : "Enviar notificación",
    "Activity notification configuration" : "Configuración de notificaciones de actividad",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de que puedas recibir correos de notificación",
    "Send activity emails" : "Enviar correos de actividades",
    "As soon as possible" : "Lo antes posible",
    "Hourly" : "Cada hora",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "You commented" : "Comentaste",
    "Message deleted by author" : "Mensaje borrado por el autor",
    "Open {filename}" : "Abrir {Nombre_de_archivo}",
    "in {path}" : "en {path}",
    "Home" : "Inicio",
    "Could not load activities" : "No se pudieron cargar actividades",
    "Loading activities" : "Cargando actividades",
    "This stream will show events like additions, changes & shares" : "Este flujo mostrará eventos tales como añadir, cambiar & compartir",
    "No activity yet" : "Aún no tiene actividad",
    "Loading more activities" : "Cargando mas actividades",
    "No more activities." : "No hay mas actividades",
    "Could not enable RSS link" : "No se pudo habilitar el enlace RSS",
    "RSS link copied to clipboard" : "Enlace RSS copiado al portapapeles",
    "Could not copy the RSS link, please copy manually:" : "No se pudo copiar el enlace RSS, por favor cópielo manualmente:",
    "Activity settings" : "Ajustes de actividad",
    "Enable RSS feed" : "Habilitar fuente RSS",
    "RSS feed" : "Fuente RSS",
    "Copy RSS feed link" : "Copiar el enlace del feed RSS",
    "Personal notification settings" : "Ajustes de notificaciones personales",
    "Unable to load the activity list" : "No se pudo cargar la lista de actividades",
    "Choose for which activities you want to get an email or push notification." : "Escoja cuales actividades quiere enviar por correo o por notificaciones.",
    "Choose for which activities you want to get a push notification." : "Elija para qué actividades desea recibir una notificación automática.",
    "Notification" : "Notificación",
    "Enable notification emails" : "Habilitar notificaciones por email",
    "Daily activity summary" : "Resumen de actividad diaria",
    "Send daily activity summary in the morning" : "Enviar resumen de actividad diaria por la mañana",
    "Default settings" : "Configuraciones predeterminadas",
    "Configure the default notification settings for new accounts." : "Configure los ajustes de notificación predeterminados para nuevas cuentas de usuario.",
    "Unable to save the settings" : "No se ha podido guardar la configuración",
    "No more events to load" : "No hay más eventos por cargar"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
